# Changelog for Wartungsplan

## Under development

 -

## Version 0.4

 - RRules now support lists like BYDAY=MO,TU,WE
 - The directory option in config now has the more explanatory name calendarfile
 - The config option ticekttitel no longer exists since it should always be
   given in the event Summary
 - OTRS: the event Summary is now correctly assigned to ticket title
